@@ -103,10 +103,25 @@ class TableParserMetro(Extractor, HTMLParser.HTMLParser):
 
       res = re.findall('<div class="trafic">(.+?)</div>', str, re.DOTALL)
       if res:
-         for perturbation in res:
-            p = re.sub('<.+?>', '',perturbation).strip().replace('&#39;', "'")
-            if p.find('Trafic normal')==-1:
-               self.rideModel.AddPerturbation( unicode(p, 'utf-8') )
+         for p in res:
+            s = 'alt=["\']\s*Ligne %s["\'].+?(?:</b|<br)>(.+?)(?:<img.+?alt=["\']M)'%self.ligne
+            r = re.search(s, p, re.DOTALL)
+            
+            if not r:
+               s = 'alt=["\']\s*Ligne %s["\'].+?(?:</b|<br)>(.+?)(?:<b>Trafic normal)'%self.ligne
+               r = re.search(s, p, re.DOTALL)
+               if not r:
+                  continue
+
+            p=r.group(1)
+            if not p:
+               continue
+         
+            p=p.replace('\n',' ').replace('<br>', '\n')
+            p=re.sub('\s+', ' ', p)
+            p = re.sub('<.+?>', '', p).strip().replace('&#39;', "'")
+
+            self.rideModel.AddPerturbation( unicode(p, 'utf-8') )
 
 class ExtractorMetro(TableParserMetro):
    def __init__(self, ligne):
