@@ -60,7 +60,7 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
       if self.tagHeurePassage:
          heure = data.strip()
          voie=''
-         res = re.search("(.+?)\s[^v]*V.+?(\d+)", heure)
+         res = re.search("(.*?)\s*[^v]*V.+?(\d+)", heure)
          if res:
             heure = res.group(1).strip()
             voie = res.group(2).strip()
