@@ -42,6 +42,12 @@ class RideModel(QtCore.QObject):
       self.total=0
       self.progress=0.0
 
+   def __str__(self):
+      s = u''
+      for ride in self.getRides():
+         s += unicode(ride)+u'\n'
+      return s
+      
    def Clear(self):
       DebugLog("RideModel::Clear")
       self.rides = []
